
#import "MBECapabilities.h"

@interface MBEDeviceCapabilities ()
@property (strong) id<MTLDevice> device;
@end

@implementation MBEDeviceCapabilities

+ (instancetype)capabilitiesWithDevice:(id<MTLDevice>)device
{
    return [[self alloc] initWithDevice:device];
}

- (instancetype)initWithDevice:(id<MTLDevice>)device
{
    if ((self = [super init]))
    {
        _device = device;
    }
    return self;
}

- (NSUInteger)highestSupportedFeatureSet
{
    const NSUInteger maxKnownFeatureSet = MTLFeatureSet_iOS_GPUFamily2_v1;
    
    for (int featureSet = maxKnownFeatureSet; featureSet >= 0; --featureSet)
    {
        if ([self.device supportsFeatureSet:featureSet])
        {
            return featureSet;
        }
    }
    
    return MTLFeatureSet_iOS_GPUFamily1_v1;
}

- (NSUInteger)featureSetGPUFamily
{
    switch (self.highestSupportedFeatureSet)
    {
        case MTLFeatureSet_iOS_GPUFamily2_v1:
            return 2;
        case MTLFeatureSet_iOS_GPUFamily1_v1:
        default:
            return 1;
    }
}

- (NSUInteger)featureSetVersion
{
    return 1;
}

- (NSUInteger)maximumRenderPassColorAttachments
{
    switch (self.highestSupportedFeatureSet)
    {
        case MTLFeatureSet_iOS_GPUFamily2_v1:
            return 8;
        case MTLFeatureSet_iOS_GPUFamily1_v1:
        default:
            return 4;
    }
}

- (BOOL)supportsASTCPixelFormats
{
    return (self.featureSetGPUFamily > 1);
}

@end
