
#import "ViewController.h"
#import <Metal/Metal.h>
#import "MBECapabilities.h"

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    id<MTLDevice> device = MTLCreateSystemDefaultDevice();
    
    MBEDeviceCapabilities *caps = [MBEDeviceCapabilities capabilitiesWithDevice:device];
    
    if (device == nil)
    {
        NSLog(@"Could not create a Metal device!");
    }
    else
    {
        NSString *deviceClassName = NSStringFromClass([device class]);
        NSLog(@"The concrete class of the device is %@", deviceClassName);
        self.deviceTypeLabel.text = deviceClassName;

        long gpuFamily = caps.featureSetGPUFamily;
        self.gpuFamilyLabel.text = [NSString stringWithFormat:@"GPU Family: %ld (%@)", gpuFamily, (gpuFamily == 1) ? @"A7" : @"A8+"];

        self.featureSetLabel.text = [NSString stringWithFormat:@"Feature Set Version: %ld", caps.featureSetVersion];
        
        self.colorAttachmentLabel.text = [NSString stringWithFormat:@"Maximum Color Attachments: %ld", caps.maximumRenderPassColorAttachments];
        
        BOOL supportsATSC = caps.supportsASTCPixelFormats;
        UIColor *atscLabelColor = supportsATSC ? [UIColor colorWithRed:0 green:0.5 blue:0 alpha:1] : [UIColor colorWithRed:0.7 green:0 blue:0 alpha:1];

        self.atscSupportLabel.attributedText = [[NSAttributedString alloc] initWithString:[NSString stringWithFormat:@"%@ ATSC Pixel Format",
                                                                                           supportsATSC ? @"Supports" : @"Does Not Support"]
                                                                               attributes:@{ NSForegroundColorAttributeName : atscLabelColor }];
    }
}

@end
